@@ -1,13 +1,16 @@
 /*
  * flood.h: header file for flood.c
  *
- * $Id: flood.h,v 1.1.1.1 1998-09-10 17:31:12 f Exp $
+ * $Id: flood.h,v 1.1 1998-09-10 17:31:12 f Exp $
  */
 
 #ifndef __flood_h_
 #define __flood_h_
 
-	int	check_flooding _((char *, int, char *));
+/**************************** PATCHED by Flier ******************************/
+	/*int	check_flooding _((char *, int, char *));*/
+        int check_flooding _((char *, char *, int, char *));
+/****************************************************************************/
 
 #define MSG_FLOOD 0
 #define PUBLIC_FLOOD 1
