@@ -56,6 +56,7 @@
 #define Server2_9	4
 #define Server2_10	5
 #define Server2_11	6
+#define Server2_12	7
 #define Server2_90	90
 
 /* Server: a structure for the server_list */
@@ -66,6 +67,7 @@ typedef	struct
 	char	*password;		/* password for that server */
 	int	port;			/* port number on that server */
 	char	*nickname;		/* nickname for this server */
+	char	*group;			/* what group the server is in */
 	char	*away;			/* away message for this server */
 	int	operator;		/* true if operator */
 	int	version;		/* the version of the server -
@@ -111,6 +113,10 @@ typedef	struct
         struct  nicks *nicklist,        /* tabkey list */
                       *nickcur;
 	ChannelList *ChanPendingList;   /* list of channels pending for join */
+        void    *compl_last;            /* pointer to last completion string */
+        void    *compl_next;            /* where to start next completion */
+        ChannelList *compl_channel;     /* last channel completion */
+
 #if defined(HAVE_SSL) || defined(HAVE_OPENSSL)
         int        enable_ssl;
 #if defined(HAVE_SSL)
@@ -136,9 +142,9 @@ typedef	unsigned	short	ServerType;
 
 	int	find_server_group _((char *, int));
 	char *	find_server_group_name _((int));
-	void	add_to_server_list _((char *, int, char *, char *, int));
+	void	add_to_server_list _((char *, int, char *, char *, char *, int));
 	void	build_server_list _((char *));
-	int	connect_to_server _((char *, int, char *, int));
+	int	connect_to_server _((char *, int, char *, char *, int));
 /**************************** PATCHED by Flier ******************************/
 	/*void	get_connected _((int));*/
 	void	get_connected _((int, int));
@@ -207,6 +213,7 @@ extern	SGroup	*server_group_list;
         int     is_server_valid _((int));
 /****************************************************************************/
 	int	get_server_port _((int));
+	char	*get_server_group _((int));
 	char	*set_server_password _((int, char *));
 	void	set_server_nickname _((int, char *));
 	void	set_server_2_6_2 _((int, int));
