@@ -33,7 +33,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: input.c,v 1.24 2006/10/31 12:31:27 f Exp $
+ * $Id: input.c,v 1.27 2008-10-04 17:37:46 f Exp $
  */
 
 #include "irc.h"
@@ -554,6 +554,9 @@ update_input(update)
 	if (update != NO_UPDATE)
 	{
 #ifdef HAVE_ICONV_OPEN
+/**************************** PATCHED by Flier ******************************/
+            if (display_conv != (iconv_t) (-1))
+/****************************************************************************/
 		iconv_close(display_conv);
 #endif /* HAVE_ICONV_OPEN */
 	}
@@ -840,6 +843,19 @@ re_encode:
 	optr = (char *)output_buffer;
 	osize = sizeof output_buffer;
 	
+/**************************** PATCHED by Flier ******************************/
+        if (mbdata.conv_in == NULL) {
+            size_t cnt = isize < osize ? isize : osize;
+
+            strmcpy(output_buffer, input_buffer, cnt + 1);
+            while (cnt > 0) {
+                optr++;
+                cnt--;
+            }
+            retval = 0;
+        }
+        else
+/****************************************************************************/
 	retval = iconv(mbdata.conv_in,
 		       &iptr, &isize,
 		       (char **)&optr, &osize);
@@ -855,6 +871,22 @@ re_encode:
 			}
 			case EILSEQ:
 			{
+/**************************** PATCHED by Flier ******************************/
+                                static time_t lastkeypress = 0;
+
+                                if (lastkeypress == 0) lastkeypress = time(NULL);
+                                else {
+                                    time_t timenow = time(NULL);
+
+                                    if (timenow - lastkeypress > 2) {
+                                        /* Probably bad input encoding, ignore bad bytes! */
+                                        say("Wrong input sequence, resetting");
+                                        input_pos = 0;
+                                        input_buffer[0] = '\0';
+                                        return;
+                                    }
+                                }
+/****************************************************************************/
 				/* User gave a bad byte. Ignore bad bytes! */
 				memmove(input_buffer+1,
 				        input_buffer,
@@ -899,6 +931,13 @@ set_input(str)
 #endif /* HAVE_ICONV_OPEN */
 	for (dest = 0; *str != '\0'; )
 	{
+/**************************** PATCHED by Flier ******************************/
+                if (*str == REV_TOG || *str == UND_TOG || *str == BOLD_TOG ||
+                    *str == ALL_OFF || *str == '\007') {
+                    converted_input[dest++] = *str++;
+                    continue;
+                }
+/****************************************************************************/
 		if (dest + 8 >= sizeof(converted_input))
 			break;
 
@@ -953,10 +992,17 @@ get_input()
 	static u_char converted_buffer[INPUT_BUFFER_SIZE];
 
 #ifdef HAVE_ICONV_OPEN
-	iconv_t conv = iconv_open(irc_encoding, "UTF-8");
+	iconv_t conv = (iconv_t) (-1);
 	char* dest = (char *)converted_buffer;
 	size_t left, space;
 
+/**************************** PATCHED by Flier ******************************/
+	if (irc_encoding) conv = iconv_open(irc_encoding, "UTF-8");
+        if (conv == (iconv_t) (-1)) {
+            strmcpy(dest, source, sizeof(converted_buffer));
+            return(converted_buffer);
+        }
+/****************************************************************************/
 	left = strlen(source);
 	space  = sizeof(converted_buffer);
 	while (*source != '\0')
