@@ -34,9 +34,9 @@
  * $Id: irc.c,v 1.138 2009-12-21 15:08:26 f Exp $
  */
 
-#define IRCII_VERSION	"20091223"	/* YYYYMMDD */
+#define IRCII_VERSION	"20131229"	/* YYYYMMDD */
 /**************************** PATCHED by Flier ******************************/
-#define SCROLLZ_VERSION "2.1"
+#define SCROLLZ_VERSION "2.2.3"
 /****************************************************************************/
 
 #include "irc.h"
@@ -265,7 +265,7 @@ char  defban;
 char  bold=2;
 char  *DefaultServer=(char *) 0;
 char  *ScrollZstr=(char *) 0;
-char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (23.12.2009)+Cdcc v" CDCC_VERSION;
+char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (29.12.2013)+Cdcc v" CDCC_VERSION;
 char  *ScrollZver1=(char *) 0;
 #ifdef EXTRA_STUFF
 char  *EString=(char *) 0;
@@ -612,6 +612,14 @@ char VersionInfo[] = {
     'i',
     'S',
     'H',
+#endif
+#ifdef SZTRACE
+    ' ',
+    'T',
+    'R',
+    'A',
+    'C',
+    'E',
 #endif
     '\0'};
 /*****************************/
@@ -646,6 +654,7 @@ irc_exit(quit)
 		new_stty("sane");
 #endif /* ESIX */
 /**************************** PATCHED by Flier ******************************/
+                term_close();
 #ifdef SZNCURSES
                 endwin();
 #endif /* SZNCURSES */
@@ -1011,6 +1020,12 @@ parse_args(argv, argc)
 					connect_at_startup = 0;
 					break;
 /**************************** PATCHED by Flier ******************************/
+                                case '4':
+                                        set_string_var(DEFAULT_PROTOCOL_VAR, "4");
+                                        break;
+                                case '6':
+					set_string_var(DEFAULT_PROTOCOL_VAR, "6");
+					break;
                                 /* what the hell is this */
 				/*case '-':
 					if (argv[ac])
