@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ircaux.c,v 1.19 2006/10/31 12:31:27 f Exp $
+ * $Id: ircaux.c,v 1.19 2006-10-31 12:31:27 f Exp $
  */
 
 #include "irc.h"
@@ -52,6 +52,7 @@
 #include "output.h"
 #include "ircterm.h"
 #include "newio.h"
+#include "vars.h"
 
 /**************************** PATCHED by Flier ******************************/
 int DCCLowPort;
@@ -596,7 +597,10 @@ connect_by_number(service,host,nonblocking,dccget)
 #else
 	char	strhost[1025], strservice[32];
 	struct	sockaddr_storage server;
-	struct	addrinfo hints, *res, *res0;
+	struct	addrinfo hints, *res, *res0 = NULL;
+/**************************** PATCHED by Flier ******************************/
+        char	*p;
+/****************************************************************************/
 
 	strncpy(strhost, host, sizeof(strhost) - 1);
 	strhost[sizeof(strhost) - 1] = 0;
@@ -666,6 +670,7 @@ connect_by_number(service,host,nonblocking,dccget)
 	/* If strhost is empty then probably DCC connection was requested.
 	 * In this case we must use AF_INET */
 	errno = 0;
+        hints.ai_flags = AI_ADDRCONFIG;
 	if (strlen(strhost) == 0)
 	{
 		hints.ai_family = AF_INET;
@@ -673,7 +678,18 @@ connect_by_number(service,host,nonblocking,dccget)
 	}
 	else
 	{
-		hints.ai_family = AF_UNSPEC;
+/**************************** PATCHED by Flier ******************************/
+		/*hints.ai_family = AF_UNSPEC;*/
+            p = get_string_var(DEFAULT_PROTOCOL_VAR);
+            if (p && (!strcmp(p, "4") || !my_stricmp(p, "v4") || !my_stricmp(p, "ipv4") || !my_stricmp(p, "inet")))
+                hints.ai_family = AF_INET;
+            else {
+                if (p && (!strcmp(p, "6") || !my_stricmp(p, "v6") || !my_stricmp(p, "ipv6") || !my_stricmp(p, "inet6")))
+                    hints.ai_family = AF_INET6;
+                else
+                    hints.ai_family = AF_UNSPEC;
+            }
+/****************************************************************************/
 		err = getaddrinfo(strhost, strservice, &hints, &res0);
 	}
 	if (err != 0)
@@ -700,8 +716,10 @@ connect_by_number(service,host,nonblocking,dccget)
 	if (service <= 0 && service != -2)
 	{
 #ifdef INET6
-		if (bind_local_addr(NULL, "0", s, res->ai_family) < 0)
-			return -2;
+		if (bind_local_addr(NULL, "0", s, res->ai_family) < 0) {
+                    freeaddrinfo(res0);
+                    return -2;
+                }
 		freeaddrinfo(res0);
 		if (listen(s, 1) == -1)
 		{
@@ -830,6 +848,10 @@ connect_by_number(service,host,nonblocking,dccget)
 		new_close(s);
 		return -4;
 	}
+#endif
+#ifdef INET6
+        if (res0)
+            freeaddrinfo(res0);
 #endif
 	return s;
 }
@@ -855,7 +877,7 @@ bind_local_addr(localhost, localport, fd, family)
 	memset(&hintsx, 0, sizeof(hintsx));
 	hintsx.ai_family = family;
 	hintsx.ai_socktype = SOCK_STREAM;
-	hintsx.ai_flags = AI_PASSIVE;
+	hintsx.ai_flags = AI_PASSIVE | AI_ADDRCONFIG;
 	err = getaddrinfo(localhost, localport, &hintsx, &res0x);
 
 	if (err != 0)
