@@ -51,6 +51,7 @@
 /**************************** PATCHED by Flier ******************************/
 #include "myvars.h"
 #include "whowas.h"
+#include "trace.h"
 
 #include <sys/time.h>
 #include <unistd.h>
@@ -265,8 +266,6 @@ add_channel(channel, server, connected, copy, key, nowho)
             }
             new = whowaschan->channellist;
             new->next = (ChannelList *) 0;
-            if ((new->window = is_bound(channel, server)) == (Window *) 0)
-                new->window = curr_scr_win;
             do_add = 1;
             add_to_list((List **) &server_list[server].chan_list, (List *) new);
             new_free(&whowaschan);
@@ -284,8 +283,6 @@ add_channel(channel, server, connected, copy, key, nowho)
 		malloc_strcpy(&new->channel, channel);
 		new->mode = 0;
 		new->limit = 0;
-		if ((new->window = is_bound(channel, server)) == (Window *) 0)
-			new->window = curr_scr_win;
 		do_add = 1;
 		add_to_list((List **) &server_list[server].chan_list, (List *) new);
 /**************************** PATCHED by Flier ******************************/
@@ -358,6 +355,13 @@ add_channel(channel, server, connected, copy, key, nowho)
                     new->topicwho = NULL;
                     for (i = 0; i < HASHTABLESIZE; i++) new->nickshash[i] = (struct hashstr *) 0;
                 }
+                if ((new->window = is_bound(channel, server)) == (Window *) 0)
+                    new->window = curr_scr_win;
+                Trace(SZ_TRACE_WINDOW, "channel %s bound to window %d (%s) (%p)",
+                      channel,
+                      new->window ? new->window->refnum : -1,
+                      new->window ? EMPTY_STR(new->window->name) : "",
+                      new->window);
 /****************************************************************************/
 		clear_channel(new);
 	}
@@ -392,6 +396,8 @@ add_channel(channel, server, connected, copy, key, nowho)
 					set_channel_by_refnum(tmp->refnum, channel);
 					new->window = tmp;
 					update_all_status();
+                                        Trace(SZ_TRACE_WINDOW, "adding channel %s", channel);
+                                        TraceWindowInfo(2, tmp);
 					return;
 				}
 				else if (!possible)
@@ -403,10 +409,14 @@ add_channel(channel, server, connected, copy, key, nowho)
 			set_channel_by_refnum(possible->refnum, channel);
 			new->window = possible;
 			update_all_status();
+                        Trace(SZ_TRACE_WINDOW, "adding channel %s", channel);
+                        TraceWindowInfo(2, possible);
 			return;
 		}
 		set_channel_by_refnum(0, channel);
 		new->window = curr_scr_win;
+                Trace(SZ_TRACE_WINDOW, "adding channel %s to current window", channel);
+                TraceWindowInfo(2, curr_scr_win);
 	}
 	update_all_windows();
 }
@@ -563,6 +573,7 @@ ChannelList *add_to_channel(channel, nick, server, oper, halfop, voice, userhost
                 if (userhost &&
                     (whowas = check_whowas_buffer(nick, userhost, channel, 1))) {
                     new = whowas->nicklist;
+                    new_free(&whowas->channel);
                     new_free(&whowas);
                     snprintf(tmpbuf, sizeof(tmpbuf), "%s!%s", nick, userhost);
                     if (!(new->frlist &&
@@ -586,6 +597,8 @@ ChannelList *add_to_channel(channel, nick, server, oper, halfop, voice, userhost
                     new->minuso = tmp ? tmp->minuso : 0;
                     new->plusb = tmp ? tmp->plusb : 0;
                     new->minusb = tmp ? tmp->minusb : 0;
+                    new->plush = tmp ? tmp->plush : 0;
+                    new->minush = tmp ? tmp->minush : 0;
                     new->kick = tmp ? tmp->kick : 0;
                     new->nickc = tmp ? tmp->nickc : 0;
                     new->publics = tmp ? tmp->publics : 0;
@@ -915,7 +928,7 @@ char    *servmodes;
 				if (add) {
 					/* we can only have one of ohv on a hybrid7 server.
 				   	   +v, +h, -h != +v */
-					if (get_server_version(server) == Server2_11)
+					if (get_server_version(server) == Server2_12)
 						*chop &= ~CHAN_VOICE;
 
 					*chop |= CHAN_HALFOP;
@@ -965,7 +978,7 @@ char    *servmodes;
                         }
 			if (ThisNick) {
 				ThisNick->halfop = add;
-				if (add && get_server_version(server) == Server2_11)
+				if (add && get_server_version(server) == Server2_12)
 					ThisNick->hasvoice = 0;
 			}
 			if (check && tmpjoiner) {
@@ -995,7 +1008,7 @@ char    *servmodes;
                                 if (add) {
 					/* we can only have one of ohv on a hybrid7 server.
 					   +h, +o, -o != +h */
-					if (get_server_version(server) == Server2_11)
+					if (get_server_version(server) == Server2_12)
 						*chop &= ~(CHAN_HALFOP | CHAN_VOICE);
 
 					*chop |= CHAN_CHOP;
@@ -1142,7 +1155,7 @@ char    *servmodes;
 			{
 				ThisNick->chanop = add;
 
-				if (add && get_server_version(server) == Server2_11)
+				if (add && get_server_version(server) == Server2_12)
 					ThisNick->halfop = ThisNick->hasvoice = 0;
 			}
 			break;
@@ -1647,7 +1660,13 @@ free_channel(channel)
         for (nick=(*channel)->nicks;nick;) {
             tmpnick=nick;
             nick=nick->next;
-            add_to_whowas_buffer(tmpnick,(*channel)->channel);
+            if (tmpnick && tmpnick->userhost)
+                add_to_whowas_buffer(tmpnick,(*channel)->channel);
+            else {
+                /* in case of /JOIN -NOWHO #channel */
+                new_free(&tmpnick->nick);
+                new_free(&tmpnick);
+            }
         }
         (*channel)->nicks=(NickList *) 0;
         if (!(add_to_whowas_chan_buffer((*channel)))) {
@@ -1682,6 +1701,16 @@ remove_channel(channel, server)
 			tmp = lookup_channel(channel, server, CHAN_UNLINK);
 			if (tmp->window)
 				refnum = tmp->window->refnum;
+/**************************** PATCHED by Flier ******************************/
+                        if (server_list[server].compl_last == tmp->channel ||
+                            server_list[server].compl_channel == tmp ||
+                            server_list[server].compl_next == tmp)
+                        {
+                            server_list[server].compl_last = NULL;
+                            server_list[server].compl_next = NULL;
+                            server_list[server].compl_channel = NULL;
+                        }
+/****************************************************************************/
 			free_channel(&tmp);
 		}
 
@@ -1697,6 +1726,11 @@ remove_channel(channel, server)
 			free_channel(&tmp);
 		}
 		server_list[server].chan_list = (ChannelList *) 0;
+/**************************** PATCHED by Flier ******************************/
+                server_list[server].compl_last = NULL;
+                server_list[server].compl_next = NULL;
+                server_list[server].compl_channel = NULL;
+/****************************************************************************/
 	}
 	update_all_windows();
 }
@@ -1770,6 +1804,13 @@ remove_from_channel(channel, nick, server)
 				new_free(&tmp);*/
                                 remove_nick_from_hash(chan,tmp);
                                 add_to_whowas_buffer(tmp,channel);
+                                if (server_list[curr_scr_win->server].compl_last == tmp->nick ||
+                                    server_list[curr_scr_win->server].compl_next == tmp)
+                                {
+                                    server_list[server].compl_last = NULL;
+                                    server_list[server].compl_next = NULL;
+                                }
+
 /****************************************************************************/
 			}
 		}
@@ -1785,6 +1826,12 @@ remove_from_channel(channel, nick, server)
 				new_free(&tmp);*/
                                 remove_nick_from_hash(chan,tmp);
                                 add_to_whowas_buffer(tmp,chan->channel);
+                                if (server_list[curr_scr_win->server].compl_last == tmp->nick ||
+                                    server_list[curr_scr_win->server].compl_next == tmp)
+                                {
+                                    server_list[server].compl_last = NULL;
+                                    server_list[server].compl_next = NULL;
+                                }
 /****************************************************************************/
 			}
 		}
@@ -1826,6 +1873,8 @@ rename_nick(old_nick, new_nick, server)
 			{
 /**************************** PATCHED by Flier ******************************/
                                 remove_nick_from_hash(chan,tmp);
+                                Trace(SZ_TRACE_NICK, "nick rename %s -> %s in %s",
+                                      old_nick, new_nick, chan->channel);
 /****************************************************************************/
 				new_free(&tmp->nick);
 				malloc_strcpy(&tmp->nick, new_nick);
@@ -2108,6 +2157,9 @@ reconnect_all_channels(server)
 /****************************************************************************/
 
 /**************************** PATCHED by Flier ******************************/
+    Trace(SZ_TRACE_CHANNEL, "reconnecting all channels for server %d", server);
+    TraceChannelInfo(2, server_list[server].chan_list);
+
         /*for (tmp = server_list[server].chan_list; tmp; tmp = tmp->next)*/
         for (tmp = server_list[server].chan_list; tmp; tmp = next)
 /****************************************************************************/
@@ -2149,6 +2201,10 @@ reconnect_all_channels(server)
                 }
 /****************************************************************************/
 	}
+/**************************** PATCHED by Flier ******************************/
+    Trace(SZ_TRACE_CHANNEL, "reconnect done");
+    TraceChannelInfo(2, server_list[server].chan_list);
+/****************************************************************************/
 }
 
 char	*
