@@ -36,7 +36,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: newio.c,v 1.15 2006/10/31 12:31:27 f Exp $
+ * $Id: newio.c,v 1.18 2008-03-30 15:31:22 f Exp $
  */
 
 #include "irc.h"
@@ -68,7 +68,9 @@
 #   define IO_ARRAYLEN NFDBITS
 #  endif /* FD_SETSIZE */
 # endif /* FDSETSIZE */
-#else /* SZ32 */
+#elif defined(__APPLE__)
+# define IO_ARRAYLEN FD_SETSIZE
+#else /* __APPLE__ */
 # ifdef OPEN_MAX
 #  define IO_ARRAYLEN OPEN_MAX
 #  else /* OPEN_MAX */
@@ -339,13 +341,22 @@ dgets(str, len, des, specials)
 }
 
 /**************************** Patched by Flier ******************************/
-#ifdef HAVE_SSL
+#if defined(HAVE_SSL) || defined(HAVE_OPENSSL)
+#if defined(HAVE_SSL)
 int SSL_dgets(str, len, des, specials, session)
 char	*str;
 int	len;
 int	des;
 char	*specials;
-gnutls_session *session;
+gnutls_session_t *session;
+#elif defined(HAVE_OPENSSL)
+int SSL_dgets(str, len, des, specials, ssl_fd)
+char	*str;
+int	len;
+int	des;
+char	*specials;
+SSL     *ssl_fd;
+#endif
 {
 	char	*ptr, ch;
  	size_t	cnt = 0;
@@ -356,8 +367,12 @@ gnutls_session *session;
 	int	i,
 		j;
 
+#if defined(HAVE_SSL)
         if (!session || !(*session)) return(0);
         if (gnutls_transport_get_ptr(*session) == NULL) return(0);
+#elif defined(HAVE_OPENSSL)
+        if (!ssl_fd) return(0);
+#endif
 	init_io();
 	if (io_rec[des] == (MyIO *) 0)
 	{
@@ -394,9 +409,14 @@ gnutls_session *session;
 				dgets_errno = 0;
 				return (-1);
 			default:
+#if defined(HAVE_SSL)
 				c = gnutls_record_recv(*session,
                                                        io_rec[des]->buffer + io_rec[des]->write_pos,
 				                       IO_BUFFER_SIZE - io_rec[des]->write_pos);
+#elif defined(HAVE_OPENSSL)
+                                c = SSL_read(ssl_fd, io_rec[des]->buffer + io_rec[des]->write_pos,
+                                             IO_BUFFER_SIZE-io_rec[des]->write_pos);
+#endif
 				if (c <= 0)
 				{
 					if (c == 0)
