@@ -179,9 +179,7 @@ parse_server_notice(from, to, line)
                 {
 #if defined(OPERVISION) && defined(WANTANSI)
                         if (OperV &&
-                           (get_server_version(from_server)==Server2_9 || 
-                            get_server_version(from_server)==Server2_10 ||
-                            get_server_version(from_server)==Server2_11) &&
+                           (get_server_version(from_server)==Server2_11) &&
                            IsIrcNetOperChannel(to))
                             OVformat(line,NULL);
                         else
@@ -317,7 +315,10 @@ parse_notice(from, Args)
  						goto out;
 					}
 					level = set_lastlog_msg_level(LOG_NOTICE);
-					no_flooding = check_flooding(from, NOTICE_FLOOD, line);
+/**************************** PATCHED by Flier ******************************/
+					/*no_flooding = check_flooding(from, NOTICE_FLOOD, line);*/
+					no_flooding = check_flooding(from, to, NOTICE_FLOOD, line);
+/****************************************************************************/
 
  					if (sed == 0 || do_hook(ENCRYPTED_NOTICE_LIST, "%s %s %s", from, to, line))
 					{
@@ -514,10 +515,12 @@ got_initial_version(line)
 		set_server_version(parsing_server_index, Server2_10);
 /**************************** Patched by Flier ******************************/
         /* this is here so we can identify Freenode servers */
-	else if (strstr(version, "hyperion"))
-		set_server_version(parsing_server_index, Server2_90);
-	else
-		set_server_version(parsing_server_index, Server2_11);
+        else if (strstr(version, "hyperion"))
+                set_server_version(parsing_server_index, Server2_90);
+        else if (!strncmp(version, "2.11", 4))
+                set_server_version(parsing_server_index, Server2_11);
+        else
+                set_server_version(parsing_server_index, Server2_12);
 /****************************************************************************/
 	malloc_strcpy(&server_list[parsing_server_index].version_string, version);
 	set_server_itsname(parsing_server_index, server);
