@@ -499,7 +499,8 @@ password_sendline(data, line)
 	new_server = atoi(data);
 	set_server_password(new_server, line);
 	connect_to_server(get_server_name(new_server),
-		get_server_port(new_server), get_server_nickname(new_server), -1);
+		get_server_port(new_server), get_server_nickname(new_server),
+		get_server_group(new_server), -1);
 }
 
 /*
@@ -549,8 +550,10 @@ nickname_sendline(data, nick)
 		if (nick && *nick)
 		{
 /**************************** PATCHED by Flier ******************************/
+                    if (is_server_connected(new_server)) {
                         SentNick++;
                         malloc_strcpy(&OldNick, get_server_nickname(new_server));
+                    }
 /****************************************************************************/
 			send_to_server("NICK %s", nick);
 			if (new_server == primary_server)
@@ -777,12 +780,10 @@ cannot_join_channel(from, ArgList)
 		return;
 
 /**************************** Patched by Flier ******************************/
-        /* handle ircd 2.9/2.10 here because numeric 477 has totally
+        /* handle ircd 2.11 here because numeric 477 has totally
            different meaning than on networks with NickServ */
         if ((-current_numeric == 477) &&
-            ((get_server_version(from_server) == Server2_9) ||
-             (get_server_version(from_server) == Server2_10) ||
-             (get_server_version(from_server) == Server2_11))) {
+            (get_server_version(from_server) == Server2_11)) {
             PasteArgs(ArgList, 0);
             if (do_hook(current_numeric, "%s %s", from, *ArgList))
                 put_it("%s%s", numeric_banner(), ArgList[0]);
@@ -894,8 +895,9 @@ cannot_join_channel(from, ArgList)
             ChannelList *tmpchan = server_list[from_server].ChanPendingList;
             if (tmpchan) {
                 server_list[from_server].ChanPendingList = tmpchan->next;
-                send_to_server("%s %s %s %s", tmpchan->topicstr, tmpchan->channel,
-                        tmpchan->s_mode, tmpchan->key);
+                send_to_server("%s %s %s %s", EMPTY_STR(tmpchan->topicstr),
+                               EMPTY_STR(tmpchan->channel), EMPTY_STR(tmpchan->s_mode),
+                               EMPTY_STR(tmpchan->key));
                 new_free(&tmpchan->channel);
                 new_free(&tmpchan->key);
                 new_free(&tmpchan->s_mode);
@@ -1227,6 +1229,9 @@ numbered_command(from, comm, ArgList)
 	case 338:
                 whois_actually(from, ArgList);
                 break;
+	case 378: /* freenode */
+                whois_connecting(from, ArgList);
+                break;
 /****************************************************************************/
 
 	case 321:		/* #define RPL_LISTSTART        321 */
@@ -1310,7 +1315,12 @@ numbered_command(from, comm, ArgList)
 			break;
 		PasteArgs(ArgList, 0);
 		flag = do_hook(current_numeric, "%s %s", from, *ArgList);
-		if (!strncmp("ISON", *ArgList, 4) || !strncmp("USERHOST",
+/**************************** PATCHED by Flier ******************************/
+		/*if (!strncmp("ISON", *ArgList, 4) || !strncmp("USERHOST",*/
+		if (!strncmp("LINKS", *ArgList, 5))
+                    inSZLinks = 0;
+                else if (!strncmp("ISON", *ArgList, 4) || !strncmp("USERHOST",
+/****************************************************************************/
 		    *ArgList, 8))
 		{
 			set_server_2_6_2(parsing_server_index, 0);
@@ -1687,6 +1697,13 @@ numbered_command(from, comm, ArgList)
                                 CdccTimeWarning();
                         }
                         break;
+		case 346:
+		case 348:
+		case 367:
+                        PasteArgs(ArgList, 0);
+                        if (do_hook(current_numeric, "%s %s", from, *ArgList))
+                            put_it("%s", ArgList[0]);
+			break;
 /****************************************************************************/
 
 		case 351:		/* #define RPL_VERSION          351 */
