@@ -62,6 +62,7 @@
 #include "list.h"
 #include "status.h"
 #include "myvars.h"
+#include "trace.h"
 
 extern void OnWho _((char *, char *, char *, char *, char *));
 extern void PrintMessage _((char *, char *, char *, int, int));
@@ -420,7 +421,10 @@ p_wall(from, ArgList)
 		else
 		{
 			level = set_lastlog_msg_level(LOG_WALL);
-			if (check_flooding(from, WALL_FLOOD, line) &&
+/**************************** PATCHED by Flier ******************************/
+			/*if (check_flooding(from, WALL_FLOOD, line) &&*/
+			if (check_flooding(from, NULL, WALL_FLOOD, line) &&
+/****************************************************************************/
 					do_hook(WALL_LIST, "%s %s", from, line))
 				put_it("%s#%s#%s %s", high, from, high, line);
 			if (beep_on_level & LOG_WALL)
@@ -477,7 +481,10 @@ p_wallops(from, ArgList)
 	{
 		if (get_int_var(USER_WALLOPS_VAR))
 		{
-			if ((flag != DONT_IGNORE) && (check_flooding(from, WALLOP_FLOOD, line)))
+/**************************** PATCHED by Flier ******************************/
+			/*if ((flag != DONT_IGNORE) && (check_flooding(from, WALLOP_FLOOD, line)))*/
+			if ((flag != DONT_IGNORE) && (check_flooding(from, NULL, WALLOP_FLOOD, line)))
+/****************************************************************************/
 			add_to_whois_queue(from, whois_new_wallops, "%s", line);
 		}
 /**************************** PATCHED by Flier ******************************/
@@ -794,7 +801,10 @@ p_privmsg(from, Args)
 		add_to_whois_queue(from, whois_ignore_msgs, "%s", ptr);
 	else
 	{
-		no_flood = check_flooding(from, flood_type, ptr);
+/**************************** PATCHED by Flier ******************************/
+		/*no_flood = check_flooding(from, flood_type, ptr);*/
+		no_flood = check_flooding(from, to, flood_type, ptr);
+/****************************************************************************/
  		if (sed == 0 || do_hook(ENCRYPTED_PRIVMSG_LIST,"%s %s %s",from, to, ptr))
 		{
 		switch (list_type)
@@ -983,7 +993,8 @@ p_quit(from, ArgList)
 
 	if (!from)
 		return;
-	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
+	/*flag = double_ignore(from, FromUserHost, IGNORE_CRAP);*/
+	flag = double_ignore(from, FromUserHost, IGNORE_QUIT);
  	save_message_from();
 	if (flag != IGNORED)
 	{
@@ -1263,9 +1274,7 @@ p_channel(from, ArgList)
 			add_channel(channel, parsing_server_index, CHAN_JOINED, NULL, NULL,
                                     chan ? chan->gotwho : 0);
                         chan = lookup_channel(channel, parsing_server_index, 0);
-                        if ((get_server_version(parsing_server_index) == Server2_9 || 
-                             get_server_version(parsing_server_index) == Server2_10 ||
-                             get_server_version(parsing_server_index) == Server2_11) &&
+                        if ((get_server_version(parsing_server_index) == Server2_11) &&
                             IsIrcNetOperChannel(channel)) {
                             snprintf(tmpbuf,sizeof(tmpbuf), "MODE %s", channel);
                         }
@@ -1503,15 +1512,24 @@ p_nick(from, ArgList)
 
 	if (!from)
 		return;
-	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
+	/*flag = double_ignore(from, FromUserHost, IGNORE_CRAP);*/
+	flag = double_ignore(from, FromUserHost, IGNORE_NICK);
 	line = ArgList[0];
 /**************************** Patched by Flier ******************************/
 	/*if (my_stricmp(from, get_server_nickname(parsing_server_index)) == 0) {*/
+        Trace(SZ_TRACE_NICK, "nick change %s -> %s", from, line);
+        Trace(SZ_TRACE_NICK, "SentNick %d   OldNick %s  my nick %s", SentNick,
+              OldNick ? OldNick : empty_string,
+              get_server_nickname(parsing_server_index));
 	if ((SentNick && !my_stricmp(from, OldNick)) ||
             !my_stricmp(from, get_server_nickname(parsing_server_index))) {
 /****************************************************************************/
 		if (parsing_server_index == primary_server)
  			malloc_strcpy(&nickname, line);
+/**************************** Patched by Flier ******************************/
+                Trace(SZ_TRACE_NICK, "nick set server nickname for server %d to %s",
+                      parsing_server_index, line);
+/****************************************************************************/
 		set_server_nickname(parsing_server_index, line);
 		its_me = 1;
 /**************************** Patched by Flier ******************************/
@@ -1923,6 +1941,9 @@ irc2_parse_server(line)
 	if (*end == '\r')
 		*end-- = '\0';
 
+/**************************** Patched by Flier ******************************/
+        Trace(SZ_TRACE_IO, "<-- %d: %s", parsing_server_index, line);
+/****************************************************************************/
 	if (*line == ':')
 	{
 		if (!do_hook(RAW_IRC_LIST, "%s", line + 1))
