@@ -1800,6 +1800,11 @@ split_up_line(str)
 			else
 				malloc_strcpy(&temp, &(lbuf[start]));
 			malloc_strcpy(&output[line++], temp);
+/**************************** PATCHED by Flier ******************************/
+                        /* do not overflow the buffer */
+                        if (line >= MAXIMUM_SPLITS)
+                            break;
+/****************************************************************************/
 			lbuf[word_break] = c;
 			lbuf[word_break+1] = c1;
 			start = word_break;
@@ -2000,7 +2005,10 @@ add_to_screen(incoming)
 	{
 		puts(incoming);
 		fflush(stdout);
-		return;
+/**************************** PATCHED by Flier ******************************/
+		/*return;*/
+        return NULL;
+/****************************************************************************/
 	}
 	/* Handles output redirection first */
 	if (!in_redirect && current_screen->redirect_name &&
@@ -2772,6 +2780,9 @@ display_lastlog_lines(start, end, window)
 	Display	*Disp;
 	char	*Line;
 	int	i;
+/**************************** PATCHED by Flier ******************************/
+        int     has_next = 0;
+/****************************************************************************/
 
 	(void)next_line_back(window);
 
@@ -2779,8 +2790,12 @@ display_lastlog_lines(start, end, window)
 		(void)next_line_back(NULL);
 
  	/* WTF is this? -krys */
-	for (i = 0, Disp = window->top_of_display; i < window->display_size;
-			Disp = Disp->next, i++)
+/**************************** PATCHED by Flier ******************************/
+	/*for (i = 0, Disp = window->top_of_display; i < window->display_size;
+			Disp = Disp->next, i++)*/
+        for (i = 0, Disp = window->top_of_display; i < window->display_size &&
+             has_next; Disp = Disp->next, i++)
+/****************************************************************************/
 		if (Disp->linetype)
 			(void)next_line_back(NULL);
 
