@@ -1265,7 +1265,10 @@ make_status_one(window, k, l)
 			
 			/* Delete the marker */
 			/* FIXME: strcpy may not be used for overlapping buffers */
-			strcpy(lbuf+i, lbuf+i+1);
+/**************************** PATCHED by Flier ******************************/
+			/*strcpy(lbuf+i, lbuf+i+1);*/
+                        memmove(lbuf + i, lbuf + i + 1, strlen(lbuf + i + 1) + 1);
+/****************************************************************************/
 			
 			rjustifypos = i;
 		}
@@ -1350,8 +1353,7 @@ status_server(window)
 			{
 				name = get_server_name(window->server);
 				rest = (char *) index(name, '.');
-				if (rest != NULL && my_strnicmp(name, "irc", 3) != 0 &&
-				    my_strnicmp(name, "icb", 3) != 0)
+				if (rest != NULL && my_strnicmp(name, "irc", 3) != 0)
 				{
 					if (is_number(name))
 						snprintf(lbuf, sizeof lbuf, server_format, name);
