@@ -104,9 +104,11 @@ static	void	Cnotifystring _((char *));
 static  void    SetAwayFile _((char *));
 void    SetStampFormat _((char *));
 static  void    SetStatusLines _((int));
+static  void    SetUsername _((char *));
 
 extern  void    RedrawAll _((void));
 extern  void    UpdateFloodUsers _((void));
+extern  void    SetTrace _((char *));
 
 extern  int     DCCLowPort;
 extern  int     DCCHighPort;
@@ -164,6 +166,9 @@ IrcVariable irc_variable[] =
 /****************************************************************************/
 	{ "DEBUG",			INT_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "DECRYPT_PROGRAM",		STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
+/**************************** PATCHED by Flier ******************************/
+        { "DEFAULT_PROTOCOL",		STR_TYPE_VAR,	0, NULL, NULL, 0, 0 },
+/****************************************************************************/
 	{ "DISPLAY",			BOOL_TYPE_VAR,	DEFAULT_DISPLAY, NULL, NULL, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
 	{ "DISPLAY_ANSI",		BOOL_TYPE_VAR,	DEFAULT_DISPLAY_ANSI, NULL, RedrawAll, 0, 0 },
@@ -253,6 +258,7 @@ IrcVariable irc_variable[] =
 	{ "NO_ASK_NICKNAME",		BOOL_TYPE_VAR,	DEFAULT_NO_ASK_NICKNAME, NULL, NULL, 0, 0 },
 	{ "NO_CTCP_FLOOD",		BOOL_TYPE_VAR,	DEFAULT_NO_CTCP_FLOOD, NULL, NULL, 0, 0 },
 	{ "OLD_ENCRYPT_PROGRAM",	BOOL_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
+	{ "RATE_LIMIT_JOIN",		STR_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "REALNAME",			STR_TYPE_VAR,	0, 0, set_realname, 0, VF_NODAEMON },
 	{ "SAME_WINDOW_ONLY",		BOOL_TYPE_VAR,	DEFAULT_SAME_WINDOW_ONLY, NULL, NULL, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
@@ -340,9 +346,13 @@ IrcVariable irc_variable[] =
 	{ "TAB",			BOOL_TYPE_VAR,	DEFAULT_TAB, NULL, NULL, 0, 0 },
 	{ "TAB_MAX",			INT_TYPE_VAR,	DEFAULT_TAB_MAX, NULL, NULL, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
+        { "TRACE",			STR_TYPE_VAR, 	0, NULL, SetTrace, 0, 0 },
         { "TRUNCATE_PUBLIC_CHANNEL",	BOOL_TYPE_VAR, 	DEFAULT_TRUNCATE_PUBLIC_CHANNEL, NULL, NULL, 0, 0 },
 /****************************************************************************/
 	{ "UNDERLINE_VIDEO",		BOOL_TYPE_VAR,	DEFAULT_UNDERLINE_VIDEO, NULL, NULL, 0, 0 },
+/**************************** PATCHED by Flier ******************************/
+        { "USERNAME",		STR_TYPE_VAR,	0, NULL, SetUsername, 0, 0 },
+/****************************************************************************/
 	{ "USER_INFORMATION", 		STR_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "USER_WALLOPS",		BOOL_TYPE_VAR,	DEFAULT_USER_WALLOPS, NULL, NULL, 0, 0 },
 	{ "VERBOSE_CTCP",		BOOL_TYPE_VAR,	DEFAULT_VERBOSE_CTCP, NULL, NULL, 0, 0 },
@@ -382,6 +392,7 @@ init_variables()
 	set_string_var(LASTLOG_LEVEL_VAR, DEFAULT_LASTLOG_LEVEL);
 	set_string_var(NOTIFY_HANDLER_VAR, DEFAULT_NOTIFY_HANDLER);
 	set_string_var(NOTIFY_LEVEL_VAR, DEFAULT_NOTIFY_LEVEL);
+	set_string_var(RATE_LIMIT_JOIN_VAR, DEFAULT_RATE_LIMIT_JOIN);
 	set_string_var(REALNAME_VAR, realname);
 	set_string_var(STAMP_FORMAT, DEFAULT_STAMP_FORMAT);
 	set_string_var(STATUS_FORMAT_VAR, DEFAULT_STATUS_FORMAT);
@@ -1106,4 +1117,11 @@ int value;
     set_int_var(STATUS_LINES_VAR, value);
     StatusLines = value - 1;
 }
+
+static void SetUsername(new_username)
+char *new_username;
+{
+    if (new_username) strmcpy(username, new_username, NAME_LEN);
+    else strmcpy(username, empty_string, NAME_LEN);
+}
 /****************************************************************************/
